/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * Created on 13.06.2003
 *
 *
 */
package at.spardat.xma.plugins.dummy;

import java.util.Set;
import javax.security.auth.Subject;
import javax.servlet.http.HttpSession;

import at.spardat.xma.security.LoginModuleServer;

/**
 * Dummy implementation of a server side authentication plugin.
 * This implementation checks if the subject is from
 * {@link DummyLoginModule} only by checking the class of the
 * principal. It uses no challange response procedure, so
 * its challange is constant.
 *
 * @author s2877
 */
public class DummyLoginModuleServer implements LoginModuleServer {

    /**
     * Get a constant String.
     * @return "Hello world"
     */
    public Object getPreLoginInfo(HttpSession session) {
        return "Hello world";
    }

    /**
     * Validate the principals and credentials of the given subject.
     * @param subject the subject as returned by {@link DummyLoginModule}
     * @param session is ignored
     * @return true if there is a {@link DummyContext} in the pricipals
     *      of the subject.
     *      false otherwise
     */
    public boolean login(Subject subject, HttpSession session) {
        Set knownPrinces = subject.getPrincipals(DummyContext.class);
        if(knownPrinces.size()<1) return false;
        else return true;
    }

    /**
     * does nothing
     * @return true
     */
    public boolean logout(Subject subject, HttpSession session) {
        return true;  //nothing to do.
    }

}
